@@ -25,14 +25,13 @@ class MxitGA(object):
 	def track(self, request):
 		if 'X-Forwarded-For' not in request.headers:
 			print("Doesn't look like a mxit request.")
-			return
 		try:
 			visitor = Visitor()
-			visitor.ip_address = request['X-Forwarded-For']
+			visitor.ip_address = request.headers['X-Forwarded-For']
 			#TODO: Persist sessions.
 			session = Session()
 			page = Page(request.url)
 			self.tracker.track_pageview(page, session, visitor)
 			print('Tracked page')
-		except Exception:
-			print('Problem tracking event: %s' % str(request))
\ No newline at end of file
+		except Exception as e:
+			print('Problem tracking event: %s\nProblem:\n%s' % (str(request), e))
\ No newline at end of file
